@@ -2,6 +2,8 @@
 #
 # Template::Plugin::Latex
 #
+# $Id:$
+#
 # DESCRIPTION
 #   Template Toolkit plugin for Latex
 #
@@ -23,21 +25,28 @@
 #     Andy Wardley, 27 May 2006
 #   * Removed the program pathname options on the FILTER call
 #     Andrew Ford, 05 June 2006
+#   * Totally rewritten by Andrew Ford September 2007
+#   * Version 3.00 released March 2009
 #
 #========================================================================
- 
+
 package Template::Plugin::Latex;
 
 use strict;
 use warnings;
 use base 'Template::Plugin';
 
-use LaTeX::Driver;
+use File::Spec;
+use LaTeX::Driver 0.07;
+use LaTeX::Encode;
+use LaTeX::Table;
 
-our $VERSION = 3.00_01;
-our $DEBUG   = 0 unless defined $DEBUG;
+
+our $VERSION = 3.01;           # Update "=head1 VERSION" below!!!!
+our $DEBUG; $DEBUG = 0 unless defined $DEBUG;
 our $ERROR   = '';
 our $FILTER  = 'latex';
+our $THROW   = 'latex';        # exception type
 
 #------------------------------------------------------------------------
 # constructor
@@ -52,12 +61,25 @@ sub new {
 
     # create a closure to generate filters with additional options
     my $filter_factory = sub {
-        my $context = shift;
+        my $factory_context = shift;
         my $filter_opts = ref $_[-1] eq 'HASH' ? pop : { };
         my $filter_args = [ @_ ];
         @$filter_opts{ keys %$options } = values %$options;
         return sub {
-            Template::Plugin::Latex::_filter->run($context, $filter_opts, $filter_args, @_);
+            # Template::Plugin::Latex::_filter->run($context, $filter_opts, $filter_args, @_);
+            _tt_latex_filter($class, $factory_context, $filter_opts, $filter_args, @_);
+        };
+    };
+
+    # create a closure to generate filters with additional options
+    my $encode_filter_factory = sub {
+        my $factory_context = shift;
+        my $filter_opts = ref $_[-1] eq 'HASH' ? pop : { };
+        my $filter_args = [ @_ ];
+        @$filter_opts{ keys %$options } = values %$options;
+        return sub {
+            # Template::Plugin::Latex::_filter->run($context, $filter_opts, $filter_args, @_);
+            _tt_latex_encode_filter($class, $factory_context, $filter_opts, $filter_args, @_);
         };
     };
 
@@ -65,174 +87,89 @@ sub new {
     my $plugin = sub {
         my $plugopt = ref $_[-1] eq 'HASH' ? pop : { };
         @$plugopt{ keys %$options } = values %$options;
-        Template::Plugin::Latex::_filter->run($context, $plugopt, @_ );
+        # Template::Plugin::Latex::_filter->run($context, $plugopt, @_ );
+        _tt_latex_filter($class, $context, $plugopt, {}, @_ );
     };
 
 
     # now define the filter and return the plugin
-    $context->define_filter('latex_encode', \&_tt_latex_encode_filter);
+    $context->define_filter('latex_encode', [ $encode_filter_factory => 1 ]);
     $context->define_filter($options->{filter} || $FILTER, [ $filter_factory => 1 ]);
-    return $plugin;
-}
 
-
-
-our %latex_encoding;
-
-# Greek letters
-my $i = 0;
-foreach (qw( alpha beta gamma delta epsilon zeta eta theta
-             iota kappa lamda mu nu xi omicron pi rho
-             final_sigma sigma tau upsilon phi chi psi omega ))
-{
-    $latex_encoding{chr(0x3b1+$i)} = "\\$_";
-    $latex_encoding{chr(0x391+$i)} = "\\\u$_";
-    $i++;
-}
-
-# Special Characters from http://www.cs.wm.edu/~mliskov/texsymbols.pdf
-
-my %euro = (
-    chr(0x2020) => 'dag', # Dagger
-    chr(0x2021) => 'ddag', # Double-dagger
-    chr(0xa7)   => 'S', # Section mark
-    chr(0xb6)   => 'P', # Paragraph
-    chr(0xdf)   => 'ss', # German sharp S
-    chr(0x152)  => 'OE', # French ligature OE
-    chr(0x153)  => 'oe', # French ligature oe
-    chr(0x141)  => 'L', # Polish suppressed-l
-    chr(0x142)  => 'l', # Polish suppressed-L
-    chr(0xd8)   => 'O', # Scandinavian O-with-slash
-    chr(0xf8)   => 'o', # Scandinavian o-with-slash
-    chr(0xc5)   => 'AA', # Scandinavian A-with-circle
-    chr(0xe5)   => 'aa', # Scandinavian a-with-circle
-    chr(0x131)  => 'i', # dotless i
-    chr(0x237)  => 'j', # dotless j
-    );
-
-
-sub _tt_latex_encode_filter { 
-    my $options = ref $_[-1] eq 'HASH' ? pop : { };
-    my $text = shift;
-    $text =~ s/\x{01}/\x{01}\x{02}/g;
-    $text =~ s/\\/\x{01}\x{03}/g;
-    $text =~ s/([{}&_%#^\$])/\\$1/g;
-    if (!exists $options->{use_textcomp} or !$options->{use_textcomp}) {
-        $text =~ s/([^\x00-\x80])(?![A-Za-z0-9])/$latex_encoding{$1}/sg;
-        $text =~ s/([^\x00-\x80])/$latex_encoding{$1}\{\}/sg;
-    }
-    $text =~ s/\x{01}\x{03}/\\textbackslash{}/g;
-    $text =~ s/\x{01}\x{02}/\x{01}/g;
-    return $text;
-}
-
-
-
-
-#------------------------------------------------------------------------
-#  Internal package in which to run the filter
-#------------------------------------------------------------------------
-
-package Template::Plugin::Latex::_filter;
-
-use strict;
-use warnings;
-use base 'Class::Accessor';
-
-use File::Spec;
-use File::Copy;
-use File::Path;
-
-__PACKAGE__->mk_accessors( qw(tmpdir basename basepath context options) );
-
-our $TMP_DIRNAME = 'tt2latex';     # temporary directory name
-our $TMP_DOCNAME = 'tt2latex';     # temporary file name
-our $THROW       = 'latex';        # exception type
-our $DEBUG;
-
-sub run {
-    my ($class, $context, $options, $filter_args, $text) = @_;
-
-    # Make a copy of the options hash.
-    $options = { %$options };
-
-    my $self = $class->SUPER::new({ context => $context,
-                                    options => $options });
-
-
-    my $output   = delete $options->{ output } || shift(@$filter_args) || '';
-    my $basename = $output || $TMP_DOCNAME;
-    if ($basename =~ s/(?:(.*?)\.)?(dvi|ps|pdf(?:\(dvi\)|\(ps\))?)$/$1/) {
-        $options->{format} = $2;
-    }
-
-    $basename =~ s/\.\w+$//;
-    $self->options->{basename} = $self->basename($basename);
-
-    $self->setup_tmpdir;
-    $self->setup_texinput_paths;
-    $self->create_latex_file($text);
-    
-    my $drv = LaTeX::Driver->new($options);
-
-    eval { $drv->run; };
-    
-    if (my $e = LaTeX::Driver::Exception->caught()) {
-        $self->throw("$e");
-    }
-
-    $output = $self->copy_output($output);
-    $self->cleanup;
-    return $output;
+    return bless $plugin, $class;
 }
 
 
 #------------------------------------------------------------------------
-# $self->_setup_tmpdir
+# _tt_latex_encode_filter
+#
 #
-# create a temporary directory 
 #------------------------------------------------------------------------
 
-sub setup_tmpdir {
-    my $self = shift;
+sub _tt_latex_encode_filter {
+    my ($class, $context, $options, $filter_args, @text) = @_;
+    my $text = join('', @text);
+    return latex_encode($text, %{$options});
+}
 
-    my $tmp  = File::Spec->tmpdir();
-    my $dir  = $self->options->{tmpdir};
 
-    if ($dir) {
-        $dir = File::Spec->catdir($tmp, $dir);
-        eval { mkpath($dir, 0, 0700) } unless -d $dir;
+#------------------------------------------------------------------------
+# _tt_latex_filter
+#
+#
+#------------------------------------------------------------------------
+
+sub _tt_latex_filter {
+    my ($class, $context, $options, $filter_args, @text) = @_;
+    my $text = join('', @text);
+
+    # Get the output and format options
+
+#    my $output = $options->{output};
+    my $output = delete $options->{ output } || shift(@$filter_args) || '';
+    my $format = $options->{format};
+
+    # If the output is just a format specifier then set the format to
+    # that and undef the output
+
+    if ($output =~ /^ (?: dvi | ps | pdf(?:\(\w+\))? ) $/x) {
+        ($format, $output) = ($output, undef);
+    }
+
+    # If the output is a filename then convert to a full pathname in
+    # the OUTPUT_PATH directory, outherwise set the output to a
+    # reference to a temporary variable.
+
+    if ($output) {
+        my $path = $context->config->{ OUTPUT_PATH }
+            or $class->_throw('OUTPUT_PATH is not set');
+        $output = File::Spec->catfile($path, $output);
     }
     else {
-        my $n = 0;
-        do { 
-            $dir = File::Spec->catdir($tmp, "$TMP_DIRNAME$$" . '_' . $n++);
-        } while (-e $dir);
-        eval { mkpath($dir, 0, 0700) };
+        my $temp;
+        $output = \$temp;
     }
-    $self->throw("failed to create temporary directory: $@") 
-        if $@;
-    $self->options->{basedir} = $self->tmpdir($dir);
-    return;
-}
 
-#------------------------------------------------------------------------
-# $self->create_latex_file($text)
-#
-# Create the LaTeX input file in the temporary directory.
-#------------------------------------------------------------------------
+    # Run the formatter
 
-sub create_latex_file {
-    my ($self, $text) = @_;
-    local(*FH);
-
-    # open .tex file for output
-    my $file = $self->basepath . ".tex";
-    unless (open(FH, ">$file")) {
-        $self->throw("failed to open $file for output: $!");
+    eval {
+        my $drv = LaTeX::Driver->new( source    => \$text,
+                                      output    => $output,
+                                      format    => $format,
+                                      maxruns   => $options->{maxruns},
+                                      extraruns => $options->{extraruns},
+                                      texinputs => _setup_texinput_paths($context),
+                                    );
+        $drv->run;
+    };
+    if (my $e = LaTeX::Driver::Exception->caught()) {
+        $class->_throw("$e");
     }
-    print(FH $text);
-    close(FH);
+
+    # Return the text if it was output to a scalar variable, otherwise
+    # return nothing.
+
+    return ref $output ? $$output : '';
 }
 
 
@@ -242,9 +179,8 @@ sub create_latex_file {
 # setup the TEXINPUT path environment variables
 #------------------------------------------------------------------------
 
-sub setup_texinput_paths {
-    my $self = shift;
-    my $context = $self->context;
+sub _setup_texinput_paths {
+    my ($context) = @_;
     my $template_name = $context->stash->get('template.name');
     my $include_path  = $context->config->{INCLUDE_PATH} || [];
     $include_path = [ $include_path ] unless ref $include_path;
@@ -260,101 +196,27 @@ sub setup_texinput_paths {
         }
         push @texinput_paths, $path;
     }
-    $self->options->{TEXINPUTS} = \@texinput_paths;
-}
-
-#------------------------------------------------------------------------
-# $self->output
-#
-# Create the LaTeX input file in the temporary directory.
-#------------------------------------------------------------------------
-
-sub copy_output {
-    my ($self, $output) = @_;
-    my ($data, $path, $dest, $ok);
-    local(*FH);
-
-    # construct file name of the generated document
-    my $options = $self->options;
-    my $format  = $options->{format} || '';
-    $format =~ s/\(.*\)//;
-
-    my $file = $self->basepath . '.' . ($format || 'dvi');
-
-    if ($output) {
-        $path = $self->context->config->{ OUTPUT_PATH }
-            || $self->throw('OUTPUT_PATH is not set');
-        $dest = File::Spec->catfile($path, $output);
-
-        # see if we can rename the generate file to the desired output 
-        # file - this may fail, e.g. across filesystem boundaries (and
-        # it's quite common for /tmp to be a separate filesystem
-        if (rename($file, $dest)) {
-            debug("renamed $file to $dest") if $DEBUG;
-            # success!  clean up and return nothing much at all
-            $self->cleanup;
-            return '';
-        }
-    }
-
-    # either we can't rename the file or the user hasn't specified
-    # an output file, so we load the generated document into memory
-    unless (open(FH, $file)) {
-        $self->throw("failed to open $file for input");
-    }
-    local $/ = undef;       # slurp file in one go
-    binmode(FH);
-    $data = <FH>;
-    close(FH);
-
-    # cleanup the temporary directory we created
-    $self->cleanup;
-
-    # write the document back out to any destination file specified
-    if ($output) {
-        debug("writing output to $dest\n") if $DEBUG;
-        my $error = Template::_output($dest, \$data, { binmode => 1 });
-        $self->throw($error) if $error;
-        return '';
-    }
-
-    debug("returning ", length($data), " bytes of document data\n")
-        if $DEBUG;
-
-    # or just return the data
-    return $data;
+    return  \@texinput_paths;
 }
 
 
-#------------------------------------------------------------------------
-# $self->cleanup
-#
-# cleans up the temporary directory if it exists and was not specified
-# as a configuration option
-#------------------------------------------------------------------------
-
-sub cleanup {
+sub _throw {
     my $self = shift;
-    return unless ref $self;
-    return if $self->options->{tmpdir};
-    my $tmpdir = $self->tmpdir;
-    rmtree($tmpdir) if defined($tmpdir) and -d $tmpdir;
-}
-
-sub throw {
-    my $self = shift;
-    $self->cleanup;
     die Template::Exception->new( $THROW => join('', @_) );
 }
 
-sub debug {
-    print STDERR "[latex] ", @_;
-    print STDERR "\n" unless $_[-1] =~ /\n$/;
-}
 
-sub basepath {
-    my $self = shift;
-    return File::Spec->catfile($self->tmpdir, $self->basename);
+sub table {
+    my $args  = ref($_[-1]) eq 'HASH' ? pop(@_) : { };
+    my ($table, $text);
+    eval {
+        $table = LaTeX::Table->new($args);
+        $text  = $table->generate_string;
+    };
+    if ($@) {
+        die Template::Exception->new( $THROW => $@ );
+    }
+    return $text;
 }
 
 
@@ -368,42 +230,123 @@ Template::Plugin::Latex - Template Toolkit plugin for Latex
 
 =head1 VERSION
 
-This documentation refers to C<Template::Plugin::Latex> version 3.00_01
+This documentation refers to C<Template::Plugin::Latex> version 3.01
 
 =head1 SYNOPSIS
 
-    [%  # sample Template Toolkit code
+Sample Template Toolkit code:
 
-        USE Latex;
+    [%- USE Latex;
 
-        mystr = "a, b & c" FILTER latex_encode;
+        mystr = "a, b & c" | latex_encode;
 
-        mydoc = BLOCK %]
+        FILTER latex("pdf");  -%]
 
     \documentclass{article}
     \begin{document}
-      This is a PDF document generated by 
-      LaTeX and the Template Toolkit, with some 
+      This is a PDF document generated by
+      LaTeX and the Template Toolkit, with some
       interpolated data: [% mystr %]
     \end{document}
 
-    [%  END;
+    [%  END; -%]
 
-        mydoc FILTER latex("pdf");
-
-        # eat all whitespace 
-
-     -%]
 
 =head1 DESCRIPTION
 
-This plugin allows you to use LaTeX to generate PDF, PostScript and
-DVI output files from the Template Toolkit.  
+The C<Latex> Template Toolkit plugin provides a C<latex> filter that
+allows the use of LaTeX to generate PDF, PostScript and DVI output files
+from the Template Toolkit.  The plugin uses L<LaTeX::Driver> to run the
+various LaTeX programs.
+
+Processing of the LaTeX document takes place in a temporary directory
+that is deleted once processing is complete.  The standard LaTeX
+programs (C<latex> or C<pdflatex>, C<bibtex> and C<makeindex>) are run
+and re-run as necessary until all references, indexes, bibliographies,
+table of contents, and lists of figures and tables are stable or it is
+apparent that they will not stabilize.  The format converters C<dvips>,
+C<dvipdf>, C<ps2pdf> and C<pdf2ps> are run as necessary to convert the
+output document to the requested format.  The C<TEXINPUTS> environment
+variable is set up to include the template directory and the C<INCLUDES>
+directories, so that LaTeX file inclusion commands should find the
+intended files.
+
+The output of the filter is binary data (although PDF and PostScript are
+not stictly binary).  You should be careful not to prepend or append any
+extraneous characters (even space characters) or text outside the FILTER
+block as this text will be included in the file output.  Notice in the
+example below how we use the post-chomp flags ('-') at the end of the
+C<USE> and C<END> directives to remove the trailing newline characters:
+
+    [% USE Latex(format='pdf') -%]
+    [% FILTER latex %]
+    ...LaTeX document...
+    [% END -%]
+
+If you're redirecting the output to a file via the third argument of
+the Template module's C<process()> method then you should also pass
+the C<binmode> parameter, set to a true value to indicate that it is a
+binary file.
+
+    use Template;
+
+    my $tt = Template->new({
+        INCLUDE_PATH => '/path/to/templates',
+        OUTPUT_PATH  => '/path/to/pdf/output',
+    });
+    my $vars = {
+        title => 'Hello World',
+    }
+    $tt->process('example.tt2', $vars, 'example.pdf', binmode => 1)
+        || die $tt->error();
+
+If you want to capture the output to a template variable, you can do
+so like this:
+
+    [% output = FILTER latex %]
+    ...LaTeX document...
+    [% END %]
+
+You can pass additional arguments when you invoke the filter, for
+example to specify the output format.
+
+    [% FILTER latex(format='pdf') -%]
+       ...LaTeX document...
+    [% END %]
+
+If you want to write the output to a file then you can specify an
+C<output> parameter.
+
+    [% FILTER latex(output='example.pdf') %]
+    ...LaTeX document...
+    [% END %]
+
+If you don't explicity specify an output format then the filename
+extension (e.g. 'pdf' in the above example) will be used to determine
+the correct format.
+
+You can specify a different filter name using the C<filter> parameter.
+
+    [% USE Latex(filter='pdf') -%]
+    [% FILTER pdf %]
+    ...LaTeX document...
+    [% END %]
+
+You can also specify the default output format.  This value can be
+C<latex>, C<pdf> or C<dvi>.
+
+    [% USE Latex(format='pdf') %]
+
+
+Note: the C<LaTeX::Driver> distribution includes three filter programs
+(C<latex2dvi>, C<latex2pdf> and C<latex2ps>) that use the
+C<LaTeX::Driver> package to process LaTeX source data into DVI, PDF or
+PostScript file respectively.  These programs have a C<-tt2> option to
+run their input through the Template Toolkit before processing as LaTeX
+source.  The programs do not use the C<Latex> plugin unless the template
+requests it, but they may provide an alternative way of processing
+Template Toolkit templates to generate typeset output.
 
-The C<latex> filter was distributed as part of the core Template
-Toolkit until version 2.15 released in May 2006 when it was moved into
-the separate Template-Latex distribution.  It should now be loaded as
-a plugin to enable the C<latex> filter:
 
 =head1 SUBROUTINES/METHODS
 
@@ -479,122 +422,96 @@ C<^> (superscript), C<~> (non-breakable space), C<$> (mathematics mode).
 Lists the characters that should be excluded from encoding.  By
 default no special characters are excluded, but it may be useful to
 specify C<except = "\\{}"> to allow the input string to contain LaTeX
-commands such as C<"this is \\textbf{bold} text">.
+commands such as C<"this is \textbf{bold} text">.
 
 =item C<use_textcomp>
 
 By default the C<latex_encode> filter will encode characters with the
 encodings provided by the C<textcomp> LaTeX package (for example the
-Pounds Sterling symbol is encoded as C<\\textsterling{}>).  Setting
+Pounds Sterling symbol is encoded as C<\textsterling{}>).  Setting
 C<use_textcomp = 0> turns off these encodings.
 
 =back
 
+=head2 C<table()>
 
+The C<table()> function provides an interface to the C<LaTeX::Table> module.
 
-=head1 OLD DOCUMENTATION
+The following example shows how a simple table can be set up.
 
+    [%- USE Latex;
 
-    [% USE Latex -%]
-    [% FILTER latex %]
-    ...LaTeX document...
-    [% END %] 
+        data = [ [ 'London', 'United Kingdom' ],
+                 [ 'Berlin', 'Germany'        ],
+                 [ 'Paris',  'France'         ],
+                 [ 'Washington', 'USA'        ] ] );
 
-You can specify a different filter name using the C<filter> parameter.
+        text = Latex.table( caption  = 'Capitol Cities',
+                            label    = 'table:capitols',
+                            headings = [ [ 'City', 'Country' ] ],
+                            data     = data );
+     -%]
 
-    [% USE Latex(filter='pdf') -%]
-    [% FILTER pdf %]
-    ...LaTeX document...
-    [% END %] 
+The variable C<text> will hold the LaTeX commands to typeset the table
+and can be further interpolated into a LaTeX document template.
 
-You can also specify the default output format.  This value can be
-C<latex>, C<pdf> or C<dvi>.
+=head1 DIAGNOSTICS
 
-    [% USE Latex(format='pdf') %]
+Most failures result from invalid LaTeX input and are propogated up from
+L<LaTeX::Driver>, L<LaTeX::Encode> or L<LaTeX::Table>.
 
-With the plugin loaded and a default format defined, you can now use
-the C<latex> filter.
+Failures detected in this module include:
 
-    [% FILTER latex -%]
-    \documentclass{article}
-    \begin{document}
-    This is a PDF document generated by 
-    Latex and the Template Toolkit.
-    \end{document}
-    [% END %]
+=over 4
 
-You can pass additional arguments when you invoke the filter to 
-specify the output format.
+=item C<OUTPUT_PATH is not set>
 
-    [% FILTER latex(format='pdf') -%]
-       ...LaTeX document...
-    [% END %]
-
-The template content between the C<FILTER> and C<END> directives will
-be piped to the appropriate program(s) to generate the document
-output.  This is fine if you're generating a document directly from a
-template.  For example:
-
-F<example.pdf>:
-
-    [% USE Latex(format='pdf') -%]
-    [% FILTER latex %]
-    ...LaTeX document...
-    [% END -%]
-
-The output will be a binary format PDF, PostScript or DVI file.  You
-should be careful not to prepend or append any extraneous characters
-or text outside the FILTER block as this text will be included in the
-file output.  Notice in the above example how we use the post-chomp
-flags ('-') at the end of the C<USE> and C<END> directives to remove
-the trailing newline characters.
-
-If you're redirecting the output to a file via the third argument of
-the Template module's C<process()> method then you should also pass
-the C<binmode> parameter set to a true value to indicate that it is a
-binary file.
-
-    use Template;
-    
-    my $tt = Template->new({
-        INCLUDE_PATH => '/path/to/templates',
-        OUTPUT_PATH  => '/path/to/pdf/output',
-    });
-    my $vars = {
-        title => 'Hello World',
-    }
-    $tt->process('example.tt2', $vars, 'example.pdf', binmode => 1)
-        || die $tt->error();
-
-If you want to capture the output to a template variable, you can do
-so like this:
-
-    [% output = FILTER latex %]
-    ...LaTeX document...
-    [% END %]
-
-If you want to write the output to a file then you can specify an 
-C<output> parameter.
-
-    [% FILTER latex(output='example.pdf') %]
-    ...LaTeX document...
-    [% END %]
-
-If you don't explicity specify an output format then the filename
-extension (e.g. 'pdf' in the above example) will be used to determine
-the correct format.
+an output filename was specified but the C<OUTPUT_PATH> configuration
+option has not been set.
 
+=back
 
 
 =head1 DEPENDENCIES
 
+=over 4
+
+=item L<Template>
+
+The Template Toolkit.
+
+=item L<LaTeX::Driver>
+
+Provides the logic for driving the LaTeX programs.
+
+=item L<LaTeX::Encode>
+
+Underpins the C<latex_encode> filter.
+
+=item L<LaTeX::Table>
+
+Underpins the C<table> function.
+
+=back
+
+
+=head1 INCOMPATIBILITIES
+
+The C<latex> filter was distributed as part of the core
+Template Toolkit distribution until version 2.15 (released in May 2006),
+when it was moved into the separate Template-Latex distribution.  The
+C<Latex> plugin must now be explicity to enable the C<latex> filter.
+
+
 =head1 BUGS AND LIMITATIONS
 
 The paths to the F<latex>, F<pdflatex> and F<dvips> should be
-pre-defined as part of the installation process (i.e. when you run
-C<perl Makefile.PL>).  You can specify alternate values as
-configuration options to the C<Template> constructor in the Perl
-inteface, but there are no option to specify these paths in template code as this 
+pre-defined as part of the installation process of L<LaTeX::Driver>
+(i.e. when you run C<perl Makefile.PL> for that package).  Alternative
+values can be specified from Perl code using the C<program_path> class
+method from that package, but there are deliberately no options to
+specify these paths from TT code.
+
 
 =head1 AUTHOR
 
@@ -603,11 +520,12 @@ Andrew Ford E<lt>a.ford@ford-mason.co.ukE<gt> (current maintainer)
 Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
 
 The original Latex plugin on which this is based was written by Craig
-Barratt with additions for Win32 by Richard Tietjen.
+Barratt with additions for Win32 by Richard Tietjen.  The code has
+subsequently been radically refactored by Andrew Ford.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2006-2007 Andrew Ford.  All Rights Reserved.
+Copyright (C) 2006-2009 Andrew Ford.  All Rights Reserved.
 
 Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
 
@@ -620,13 +538,15 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 =head1 SEE ALSO
 
-L<Template::Latex>, L<LaTeX::Driver>
+L<Template>, L<LaTeX::Driver>, L<LaTeX::Table>, L<LaTeX::Encode>
+
+
+L<latex2dvi(1)>, L<latex2pdf(1)> and L<latex2ps(1)> (part of the
+C<LaTeX::Driver> distribution)
 
 =cut
 
 
-
-
 # Local Variables:
 # mode: perl
 # perl-indent-level: 4
